pub fn init() -> usizeExpand description
Initialize all per-CPU data areas.
The number of areas is determined by the following formula:
(percpu_section_size / align_up(percpu_area_size, 64)Returns the number of areas initialized. If this function has been called before, it does nothing and returns 0.